@@ -8,7 +8,7 @@ main() {
 
 build_distributions() {
   mkdir -p dist
-  rm dist/*
+  rm -f dist/*
   python setup.py sdist bdist_wheel
 }
 
